RDFCalendar.Writers

Package RDFCalendar :: Module Writers |
[show private | hide private]
[frames | no frames]

## Module RDFCalendar.Writers

    Writer classes.

    Copyright (C) 2005, 2006, 2007 Paul Boddie <paul@boddie.org.uk>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

Classes
`Writer` |

Function Summary
| ``get_document`(store, main_node, qualifier, value_as_attribute)` Using the given 'store', return a new DOM document containing the resource rooted at the given 'main_node', configured using the optional 'qualifier' and 'value_as_attribute' parameters.
| ``get_document_for_nodes`(store, label, nodes, qualifier, value_as_attribute)` Using the given 'store', make a new DOM document with the given 'label' on the root element containing the resources found at the given 'nodes', configured using the optional 'qualifier' and 'value_as_attribute' parameters.
| ``write_freebusy`(stream, store, start, end, organiser, attendee, attendee_as_organiser, *args, **kw)` Write to the given 'stream', using the given 'store', the free/busy information in the time period from 'start' to 'end' (where None indicates the absence of a constraint on the period), in response to the 'organiser', for the person specified as the 'attendee'.
| ``write_to_document`(doc, root, store, main_node, nodes, qualifier, value_as_attribute)` Write to the document 'doc' within the given 'root' element, using the given 'store', the 'main_node' (if specified) or the given 'nodes' (if specified instead).
| ``write_to_stream`(stream, store, main_node, nodes, *args, **kw)` Write to the given 'stream', using the given 'store', the 'main_node' (if specified) or the given 'nodes' (if specified instead).

Function Details

### get_document(store, main_node=None, qualifier=None, value_as_attribute=0)
    Using the given 'store', return a new DOM document containing the resource
    rooted at the given 'main_node', configured using the optional 'qualifier'
    and 'value_as_attribute' parameters.

### get_document_for_nodes(store, label, nodes, qualifier=None, value_as_attribute=0)
    Using the given 'store', make a new DOM document with the given 'label' on
    the root element containing the resources found at the given 'nodes',
    configured using the optional 'qualifier' and 'value_as_attribute'
    parameters.

### write_freebusy(stream, store, start, end, organiser, attendee, attendee_as_organiser=0, *args, **kw)
    Write to the given 'stream', using the given 'store', the free/busy
    information in the time period from 'start' to 'end' (where None indicates
    the absence of a constraint on the period), in response to the 'organiser',
    for the person specified as the 'attendee'.

    If the optional 'attendee_as_organiser' parameter is set to a true value
    (which is not the default), items where the specified 'attendee' is also the
    organiser of an event are included in the free/busy information.

### write_to_document(doc, root, store, main_node=None, nodes=None, qualifier=None, value_as_attribute=0)
    Write to the document 'doc' within the given 'root' element, using the given
    'store', the 'main_node' (if specified) or the given 'nodes' (if specified
    instead). The optional 'qualifier' and 'value_as_attribute' settings
    configure the resulting DOM document.

### write_to_stream(stream, store, main_node=None, nodes=None, *args, **kw)
    Write to the given 'stream', using the given 'store', the 'main_node' (if
    specified) or the given 'nodes' (if specified instead).

Generated by Epydoc 2.1 on Tue Mar 27 01:15:38 2007 | http://epydoc.sf.net